/*
 * Copyright © 2015-2016, Verizon and/or its Licensors. All rights reserved.
 */

package com.thingspace.media.activities;

import android.os.Bundle;
import android.text.TextUtils;
import android.widget.EditText;
import android.widget.TextView;

import com.thingspace.cloud.sdk.list.ItemList;
import com.thingspace.cloud.sdk.list.item.Address;
import com.thingspace.cloud.sdk.list.item.Contact;
import com.thingspace.cloud.sdk.list.item.Email;
import com.thingspace.cloud.sdk.list.item.IM;
import com.thingspace.cloud.sdk.list.item.Phone;
import com.thingspace.media.R;

/**
 * This activity is called when a contact is selected from the contacts list to display all details of the contact.
 */
public class ContactActivity extends BaseActivity {

    private static Contact contact;

    public static void setContact(Contact cItem) {
        contact = cItem;
    }

    @Override
    protected void onCreate(Bundle savedInstanceState) {
        super.onCreate(savedInstanceState);
        setContentView(R.layout.activity_contact);

        /**
         * Retrieve the appropriate name for the title.
          */
        String name = contact.getFirstName();

        if (!TextUtils.isEmpty(contact.getLastName())) {
            if (TextUtils.isEmpty(name)) {
                name = contact.getLastName();
            } else {
                name += " " + contact.getLastName();
            }
        }

        if (TextUtils.isEmpty(name)) {
            name = contact.getOrgName();
        }

        if (TextUtils.isEmpty(name)) {
            name = "Name Unavailable";
        }

        ((TextView) findViewById(R.id.textView_Name)).setText(name);

        /**
         * Get the First Name, Middle Name and Last Name of the contact.
         */
        ((EditText) findViewById(R.id.editText_FirstName)).setText(contact.getFirstName());
        ((EditText) findViewById(R.id.editText_MiddleName)).setText(contact.getMiddleName());
        ((EditText) findViewById(R.id.editText_LastName)).setText(contact.getLastName());

        // Organization
        ((EditText) findViewById(R.id.editText_OrgName)).setText(contact.getOrgName());
        ((EditText) findViewById(R.id.editText_OrgUnit)).setText(contact.getOrgUnit());
        ((EditText) findViewById(R.id.editText_JobTitle)).setText(contact.getJobTitle());


        /**
         *  Get the first Mobile, Home and Business Phone Number as saved by user
         */
        String phoneMobile = null;
        String phoneHome = null;
        String phoneBusiness = null;
        ItemList<Phone> phoneItemList = contact.getPhoneList();
        for (int i = 0; i < phoneItemList.getCount(); i++) {
            Phone phone = phoneItemList.getItem(i);
            if (phone.getIndex() == 1) {
                if ("mobile".equalsIgnoreCase(phone.getType())) {
                    phoneMobile = phone.getNumber();
                } else if ("home".equalsIgnoreCase(phone.getType())) {
                    phoneHome = phone.getNumber();
                } else if ("business".equalsIgnoreCase(phone.getType())) {
                    phoneBusiness = phone.getNumber();
                }
            }
        }

        ((EditText) findViewById(R.id.editText_phoneMobile)).setText(phoneMobile);
        ((EditText) findViewById(R.id.editText_phoneHome)).setText(phoneHome);
        ((EditText) findViewById(R.id.editText_phoneBusiness)).setText(phoneBusiness);

        /**
         * Get the first Personal, Business and Other Email Id's as saved by user
         */
        String emailPersonal = null;
        String emailBusiness = null;
        String emailOther = null;
        ItemList<Email> emailItemList = contact.getEmailList();
        for (int i = 0; i < emailItemList.getCount(); i++) {
            Email email = emailItemList.getItem(i);
            if (email.getIndex() == 1) {
                if ("personal".equalsIgnoreCase(email.getType())) {
                    emailPersonal = email.getAddress();
                } else if ("business".equalsIgnoreCase(email.getType())) {
                    emailBusiness = email.getAddress();
                } else if ("other".equalsIgnoreCase(email.getType())) {
                    emailOther = email.getAddress();
                }
            }
        }

        ((EditText) findViewById(R.id.editText_emailPersonal)).setText(emailPersonal);
        ((EditText) findViewById(R.id.editText_emailBusiness)).setText(emailBusiness);
        ((EditText) findViewById(R.id.editText_emailOther)).setText(emailOther);

        /**
         *Get the first Home, Business  and Other Address as saved by user
         */
        String addressHome = null;
        String addressBusiness = null;
        String addressOther = null;
        ItemList<Address> addressItemList = contact.getAddressList();
        for (int i = 0; i < addressItemList.getCount(); i++) {
            Address addressItem = addressItemList.getItem(i);
            if (addressItem.getIndex() == 1) {
                StringBuilder address = new StringBuilder();
                if (!TextUtils.isEmpty(addressItem.getApartment())) {
                    address.append(addressItem.getApartment());
                }
                if (!TextUtils.isEmpty(addressItem.getStreet())) {
                    address.append(" " + addressItem.getStreet());
                }
                if (!TextUtils.isEmpty(addressItem.getCity())) {
                    address.append(", " + addressItem.getCity());
                }
                if (!TextUtils.isEmpty(addressItem.getState())) {
                    address.append(", " + addressItem.getState());
                }
                if (!TextUtils.isEmpty(addressItem.getCountry())) {
                    address.append(", " + addressItem.getCountry());
                }

                if (!TextUtils.isEmpty(addressItem.getZipcode())) {
                    address.append(" - " + addressItem.getZipcode());
                }

                if ("home".equalsIgnoreCase(addressItem.getType())) {
                    addressHome = address.toString();
                } else if ("business".equalsIgnoreCase(addressItem.getType())) {
                    addressBusiness = address.toString();
                } else if ("other".equalsIgnoreCase(addressItem.getType())) {
                    addressOther = address.toString();
                }
            }
        }

        ((EditText) findViewById(R.id.editText_addressHome)).setText(addressHome);
        ((EditText) findViewById(R.id.editText_addressBusiness)).setText(addressBusiness);
        ((EditText) findViewById(R.id.editText_addressOther)).setText(addressOther);

        /**
         * Get the IM of the contact as saved by the user
         */
        StringBuilder imBuilder = new StringBuilder();

        ItemList<IM> imItemList = contact.getiMList();
        int imCount = imItemList.getCount();
        for (int i = 0; i < imCount; i++) {
            IM im = imItemList.getItem(i);
            imBuilder.append(im.getType() + ": " + im.getAddress());
            if (i + 1 < imCount) {
                imBuilder.append("\n");
            }
        }

        ((EditText) findViewById(R.id.editText_IM)).setText(imBuilder.toString());
    }
}
