/*
 * Copyright © 2015-2016, Verizon and/or its Licensors. All rights reserved.
 */

package com.thingspace.media.activities;

import android.content.Intent;
import android.os.Bundle;
import android.support.v7.widget.LinearLayoutManager;
import android.support.v7.widget.RecyclerView;
import android.support.v7.widget.Toolbar;
import android.text.TextUtils;
import android.view.View;

import com.thingspace.cloud.sdk.list.ItemList;
import com.thingspace.cloud.sdk.list.item.Contact;
import com.thingspace.cloud.sdk.list.item.Item;
import com.thingspace.cloud.sdk.list.item.Phone;
import com.thingspace.media.R;
import com.thingspace.media.adapters.OnBindViewInterface;
import com.thingspace.media.adapters.RecyclerViewListAdapter;
import com.thingspace.media.adapters.viewholders.RecyclerViewListHolder;
import com.thingspace.media.listeners.RecyclerViewClickListener;

/**
 * ContactsListActivity is called when Contacts Tab is selected from Home page which displays the list of contacts with name and phone number.
 * When each contact is selected, it calls ContactActivity which displays all details of the contact selected
 */
public class ContactsListActivity extends BaseActivity implements OnBindViewInterface, RecyclerViewClickListener {

    private static ItemList itemListContacts;
    private Toolbar toolbar;
    private RecyclerView recyclerView;

    public static void setItemList(ItemList itemList) {
        itemListContacts = itemList;
    }

    @Override
    protected void onCreate(Bundle savedInstanceState) {
        super.onCreate(savedInstanceState);
        setContentView(R.layout.resource_recycler_view);

        toolbar = (Toolbar) findViewById(R.id.toolbar);
        toolbar.setVisibility(View.VISIBLE);
        setSupportActionBar(toolbar);
        getSupportActionBar().setTitle(getString(R.string.title_activity_contacts, itemListContacts.getCount()));
        getSupportActionBar().setDisplayHomeAsUpEnabled(true);

        recyclerView = (RecyclerView) findViewById(R.id.recyclerView);
        recyclerView.setLayoutManager(new LinearLayoutManager(this));
        recyclerView.setAdapter(new RecyclerViewListAdapter(R.layout.list_item_contacts, itemListContacts, this, this));
    }

    @Override
    public void onBindView(RecyclerView.ViewHolder holder, Item item) {
        Contact contact = (Contact) item;

        String name = contact.getFirstName();

        if (!TextUtils.isEmpty(contact.getLastName())) {
            if (TextUtils.isEmpty(name)) {
                name = contact.getLastName();
            } else {
                name += " " + contact.getLastName();
            }
        }

        if (TextUtils.isEmpty(name)) {
            name = contact.getOrgName();
        }

        if (TextUtils.isEmpty(name)) {
            name = "Name Unavailable";
        }

        ((RecyclerViewListHolder) holder).textView.setText(name);

        ItemList phoneList = contact.getPhoneList();
        if (phoneList != null && phoneList.getCount() > 0) {
            ((RecyclerViewListHolder) holder).textView2.setVisibility(View.VISIBLE);
            ((RecyclerViewListHolder) holder).textView2.setText(((Phone) phoneList.getItem(0)).getNumber());
        } else {
            ((RecyclerViewListHolder) holder).textView2.setVisibility(View.GONE);
        }

        ((RecyclerViewListHolder) holder).imageView.setImageResource(R.drawable.contact_icon);
        if (contact.isFavorite()) {
            ((RecyclerViewListHolder) holder).imageView2.setVisibility(View.VISIBLE);
            ((RecyclerViewListHolder) holder).imageView2.setImageResource(R.drawable.favorite_icon);
        } else {
            ((RecyclerViewListHolder) holder).imageView2.setVisibility(View.INVISIBLE);
        }
    }

    /**
     * When each contact is selected, ContactActivity is called which displays all the details of the contact
     * @param view     image view that was clicked
     * @param position position in the recycler view
     */
    @Override
    public void onListItemClicked(View view, int position) {
        ContactActivity.setContact((Contact) itemListContacts.getItem(position));
        Intent intent = new Intent(this, ContactActivity.class);
        startActivity(intent);
    }

    @Override
    public void onListItemLongClicked(View view, int position) {

    }
}
