/*
 * Copyright © 2015-2016, Verizon and/or its Licensors. All rights reserved.
 */

package com.thingspace.media.adapters;

import android.content.Context;
import android.text.TextUtils;
import android.view.LayoutInflater;
import android.view.View;
import android.view.ViewGroup;
import android.widget.ImageView;
import android.widget.TextView;

import com.thingspace.cloud.sdk.CloudAPI;
import com.thingspace.cloud.sdk.list.ItemList;
import com.thingspace.cloud.sdk.list.item.Contact;
import com.thingspace.cloud.sdk.list.item.Email;
import com.thingspace.cloud.sdk.list.item.Phone;
import com.thingspace.media.R;

/**
 * GridCursorAdapter to inflate grid contact items
 */
public class GridCursorAdapterContacts extends GridCursorAdapter {

    public GridCursorAdapterContacts(Context context, int layout, ItemList itemList, CloudAPI cloudAPI, int count) {
        super(context, layout, itemList, cloudAPI, count);
    }

    public GridCursorAdapterContacts(Context context, int layout, ItemList itemList, CloudAPI cloudAPI) {
        super(context, layout, itemList, cloudAPI);
    }

    @Override
    public View getView(int position, View convertView, ViewGroup parent) {
        View view = LayoutInflater.from(context).inflate(layoutID, parent, false);
        final ViewHolder viewHolder = new ViewHolder((ImageView) view.findViewById(R.id.image), (TextView) view.findViewById(R.id.contact_name));
        Contact contact = (Contact) itemList.getItem(position);

        if (contact == null) {
            return view;
        }

        // getting contact thumbnail is not yet supported.
        viewHolder.imageView.setImageResource(R.drawable.contact_icon);

        String name = "N/A";
        do {
            if (!TextUtils.isEmpty(contact.getFirstName())) {
                name = contact.getFirstName();
                break;
            }

            if (!TextUtils.isEmpty(contact.getLastName())) {
                name = contact.getLastName();
                break;
            }

            if (!TextUtils.isEmpty(contact.getOrgName())) {
                name = contact.getOrgName();
                break;
            }

            String personalEmail = null;
            ItemList<Email> emailItemList = contact.getEmailList();
            for (int i = 0; i < emailItemList.getCount(); i++) {
                Email email = emailItemList.getItem(i);
                if (email.getIndex() == 1) {
                    if ("personal".equalsIgnoreCase(email.getType())) {
                        personalEmail = email.getAddress();
                        break;
                    }
                }
            }

            if (!TextUtils.isEmpty(personalEmail)) {
                name = personalEmail;
                break;
            }

            String mobilePhone = null;
            String homePhone = null;
            ItemList<Phone> phoneItemList = contact.getPhoneList();
            for (int i = 0; i < phoneItemList.getCount(); i++) {
                Phone phone = phoneItemList.getItem(i);
                if (phone.getIndex() == 1) {
                    if ("mobile".equalsIgnoreCase(phone.getType())) {
                        mobilePhone = phone.getNumber();
                    } else if ("home".equalsIgnoreCase(phone.getType())) {
                        homePhone = phone.getNumber();
                    }
                }
            }

            if (!TextUtils.isEmpty(mobilePhone)) {
                name = mobilePhone;
                break;
            }

            if (!TextUtils.isEmpty(homePhone)) {
                name = homePhone;
                break;
            }
        } while (false);

        viewHolder.textView.setText(name);

        return view;
    }

    final class ViewHolder {
        ImageView imageView;
        TextView textView;

        public ViewHolder(ImageView imageView, TextView textView) {
            this.imageView = imageView;
            this.textView = textView;
        }
    }
}
