/*
 * Copyright © 2015-2016, Verizon and/or its Licensors. All rights reserved.
 */

package com.thingspace.media.tasks;

import android.content.Context;
import android.os.Environment;
import android.util.Log;

import com.thingspace.cloud.sdk.CloudAPI;
import com.thingspace.cloud.sdk.exception.CloudAPIException;
import com.thingspace.cloud.sdk.list.item.Audio;
import com.thingspace.cloud.sdk.list.item.FullviewItem;
import com.thingspace.cloud.sdk.list.item.Photo;
import com.thingspace.cloud.sdk.list.item.Video;
import com.thingspace.media.listeners.ThingspaceResponseListener;

import java.io.File;

/**
 * Class to demonstrate Cloud SDK api call to download a file
 */
public class DownloadTask extends HubbleMediaTask {

    private String parentPath, name;
    private CloudAPI cloudAPI;

    /**
     * Download a file from user's cloud storage account.
     *
     * @param context                    Context object
     * @param thingspaceResponseListener Response listener to receive cloud api response
     * @param parentPath                 Path to the directory where the file is stored under user's cloud storage account. Can be obtained using {@link FullviewItem}, {@link Photo}, {@link Video} or {@link Audio} classes.
     * @param name                       Name of the file to be downloaded from the cloud. Can be obtained using {@link FullviewItem}, {@link Photo}, {@link Video} or {@link Audio} classes.
     * @param cloudAPI                   {@link CloudAPI} class object to access user's cloud storage account
     */
    public DownloadTask(Context context, ThingspaceResponseListener thingspaceResponseListener, String parentPath, String name, CloudAPI cloudAPI) {
        super(context, thingspaceResponseListener);
        this.parentPath = parentPath;
        this.name = name;
        this.cloudAPI = cloudAPI;
    }

    @Override
    protected Boolean executeAPIRequest(String... params) {
        if (contextWeakReference.get() == null) {
            throw new IllegalArgumentException("activity reference null");
        }

        /**
         * Obtain a path of a local existing directory or create a new directory where the file is intended to be downloaded.
         */
        File sdcard = Environment.getExternalStorageDirectory();
        File folder = new File(sdcard.getAbsoluteFile(), "VZDemoApp");
        folder.mkdir();

        /**
         * Cloud SDK api call to download a file to specified location on the device.
         */
        return cloudAPI.downloadFile(contextWeakReference.get(), parentPath, name, folder.getAbsolutePath());
    }

    protected Object onCloudAPIException(CloudAPIException ex) {
        Log.e(getClass().getSimpleName(), "Exception downloading file: " + ex);
        return null;
    }

    @Override
    protected int getTaskCode() {
        return TASK_DOWNLOAD;
    }
}
