/*
 * Copyright © 2015-2016, Verizon and/or its Licensors. All rights reserved.
 */

package com.thingspace.media.tasks;

import android.content.Context;

import com.thingspace.cloud.sdk.enums.SortType;
import com.thingspace.cloud.sdk.list.item.Album;
import com.thingspace.media.listeners.ThingspaceResponseListener;

/**
 * Cloud SDK api call to retrieve files from Photo or Music albums.
 */
public class GetAlbumFilesTask extends HubbleMediaTask {

    private Album album;
    private SortType sortType;

    /**
     * Retrieve files from Photo or Music albums.
     *
     * @param context                    context object
     * @param thingspaceResponseListener Response listener to receive cloud api response
     * @param album                      {@link Album} object to access Album files
     * @param sortType                   Sort order for the response list
     */
    public GetAlbumFilesTask(Context context, ThingspaceResponseListener thingspaceResponseListener, Album album, SortType sortType) {
        super(context, thingspaceResponseListener);
        this.album = album;
        this.sortType = sortType;
    }

    protected Object executeAPIRequest(String... params) {
        /**
         * Cloud SDK api call to retrieve files stored under an album using {@link Album} class.
         */
        return album.getFiles(contextWeakReference.get(), sortType);
    }

    @Override
    protected int getTaskCode() {
        return TASK_ALBUM_FILES;
    }
}
