/*
 * Copyright © 2015-2016, Verizon and/or its Licensors. All rights reserved.
 */

package com.thingspace.media.tasks;

import android.content.Context;

import com.thingspace.cloud.sdk.CloudAPI;
import com.thingspace.cloud.sdk.enums.SortType;
import com.thingspace.media.listeners.ThingspaceResponseListener;

/**
 * Class to demonstrate Cloud SDK api call to retrieve all photos stored under user's cloud storage account.
 */
public class GetPhotosTask extends HubbleMediaTask {

    private CloudAPI cloudAPI;
    private SortType sortType;

    /**
     * Retrieve all photos stored in the cloud.
     *
     * @param context                    context object
     * @param thingspaceResponseListener Response listener to receive cloud api response
     * @param cloudAPI                   {@link CloudAPI} object to access Cloud api
     * @param sortType                   Sort order for the response list
     */
    public GetPhotosTask(Context context, ThingspaceResponseListener thingspaceResponseListener, CloudAPI cloudAPI, SortType sortType) {
        super(context, thingspaceResponseListener);
        this.cloudAPI = cloudAPI;
        this.sortType = sortType;
    }

    protected Object executeAPIRequest(String... params) {
        /**
         * Cloud SDK api call to retrieve all photos from the cloud.
         */
        return cloudAPI.getPhotos(contextWeakReference.get(), sortType);
    }

    @Override
    protected int getTaskCode() {
        return TASK_GET_PHOTOS;
    }
}
