/*
 * Copyright © 2015-2016, Verizon and/or its Licensors. All rights reserved.
 */

package com.thingspace.media.tasks.playlist;

import android.content.Context;

import com.thingspace.cloud.sdk.CloudAPI;
import com.thingspace.cloud.sdk.enums.PlaylistType;
import com.thingspace.media.listeners.ThingspaceResponseListener;
import com.thingspace.media.tasks.HubbleMediaTask;

import java.util.ArrayList;

/**
 * Class to demonstrate create playlist api call.
 */
public class CreatePlaylistTask extends HubbleMediaTask {

    private CloudAPI cloudAPI;
    private PlaylistType playlistType;
    private String name;
    private ArrayList<String> paths;

    /**
     * Create a playlist under user's cloud storage account
     *
     * @param context                    context object
     * @param thingspaceResponseListener Response listener to receive cloud api response
     * @param cloudAPI                   {@link CloudAPI} object to access Cloud apis
     * @param name                       Intended name of the new playlist
     * @param paths                      Paths of all the files to be added to the playlist
     * @param playlistType               Type of the playlist as defined  in {@link PlaylistType}
     */
    public CreatePlaylistTask(Context context, ThingspaceResponseListener thingspaceResponseListener, CloudAPI cloudAPI, String name, ArrayList<String> paths, PlaylistType playlistType) {
        super(context, thingspaceResponseListener);
        this.cloudAPI = cloudAPI;
        this.playlistType = playlistType;
        this.name = name;
        this.paths = paths;
    }

    protected Object executeAPIRequest(String... params) {
        /**
         * Cloud SDK Method call to create a new playlist
         */
        return cloudAPI.createPlaylist(contextWeakReference.get(), name, paths, playlistType);
    }

    @Override
    protected int getTaskCode() {
        return TASK_CREATE_PLAYLIST;
    }
}
