/*
 * Copyright © 2015-2016, Verizon and/or its Licensors. All rights reserved.
 */

package com.thingspace.media.tasks.playlist;

import android.content.Context;

import com.thingspace.cloud.sdk.CloudAPI;
import com.thingspace.cloud.sdk.list.item.Playlist;
import com.thingspace.media.listeners.ThingspaceResponseListener;
import com.thingspace.media.tasks.HubbleMediaTask;

/**
 * Class to demonstrate Cloud SDK API call to Update an existing playlist by renaming it.
 */
public class UpdatePlaylistTask extends HubbleMediaTask {

    private CloudAPI cloudAPI;
    private String name, uid;

    /**
     * Update an existing playlist. This call renames the playlist.
     *
     * @param context                    context object
     * @param thingspaceResponseListener Response listener to receive cloud api response
     * @param cloudAPI                   {@link CloudAPI} object to access Cloud api
     * @param uid                        Playlist uid as obatained from {@link Playlist#getUid()}
     * @param name                       New playlist name
     */
    public UpdatePlaylistTask(Context context, ThingspaceResponseListener thingspaceResponseListener, CloudAPI cloudAPI, String uid, String name) {
        super(context, thingspaceResponseListener);
        this.cloudAPI = cloudAPI;
        this.name = name;
        this.uid = uid;
    }

    protected Object executeAPIRequest(String... params) {
        /**
         * Cloud SDK API call to update an existing playlist.
         */
        return cloudAPI.updatePlaylist(contextWeakReference.get(), uid, name);
    }

    @Override
    protected int getTaskCode() {
        return TASK_UPDATE_PLAYLIST;
    }
}
