/*
 * Copyright © 2015-2016, Verizon and/or its Licensors. All rights reserved.
 */

package com.thingspace.media.tasks.share;

import android.content.Context;

import com.thingspace.cloud.sdk.CloudAPI;
import com.thingspace.cloud.sdk.request.ShareResource;
import com.thingspace.media.listeners.ThingspaceResponseListener;
import com.thingspace.media.tasks.HubbleMediaTask;

import java.util.ArrayList;

/**
 * Class to demonstrate Cloud SDK api call to create a share with file(s), folder(s) or playlist(s).
 */
public class CreateShareTask extends HubbleMediaTask {

    private CloudAPI cloudAPI;
    private String shareName;
    private ArrayList<ShareResource> shareResources;

    /**
     * Create a share in the cloud.
     *
     * @param context                    context object
     * @param thingspaceResponseListener Response listener to receive cloud api response
     * @param cloudAPI                   {@link CloudAPI} object to access Cloud api
     * @param shareName                  The intended name of the share to be created
     * @param shareResources             An array list of the {@link ShareResource} - Information about resources to be added to the share
     */
    public CreateShareTask(Context context, ThingspaceResponseListener thingspaceResponseListener, CloudAPI cloudAPI, String shareName, ArrayList<ShareResource> shareResources) {
        super(context, thingspaceResponseListener);
        this.cloudAPI = cloudAPI;
        this.shareName = shareName;
        this.shareResources = shareResources;
    }

    protected Object executeAPIRequest(String... params) {
        /**
         * Cloud SDK api call to create a share.
         */
        return cloudAPI.createShare(contextWeakReference.get(), shareName, 10000, shareResources);
    }

    @Override
    protected int getTaskCode() {
        return TASK_CREATE_SHARE;
    }
}
