package com.thingspace.files.activity;

import android.os.Bundle;
import android.support.v7.app.AppCompatActivity;

import com.thingspace.cloud.sdk.CloudAPI;
import com.thingspace.files.R;

/**
 * BaseActivity for all application activities that uses CloudAPI.
 * This activity initializes the CloudAPI object using the application key, secret and call back urls obtained from the ThingSpace portal,
 * and performs authorization upon onResume to authenticate the user and authorize the application to access user's content from the cloud.
 */
public abstract class BaseActivity extends AppCompatActivity {

    protected CloudAPI cloudAPI;

    @Override
    protected void onCreate(Bundle savedInstanceState) {
        super.onCreate(savedInstanceState);

        /*
         * Initialize Cloud SDK API object using the Application Key, Secret and Callback URL that can be obtained from Key Management tab in ThingSpace portal.
         * Application Key, Secret and Callback URL needs to be updated in the build.gradle file
         */
        cloudAPI = new CloudAPI(getString(R.string.Client_ID), getString(R.string.Client_Secret), getString(R.string.Callback_URL));
    }

    @Override
    protected void onResume() {
        super.onResume();
        /**
         * Start authorization if user is not yet authorized.
         * Upon authorization, Login/consent screen will be displayed asking user to grant verizon cloud access to the application.
         * After authorization is completed, onResume of this activity will be called.
         */
        if (cloudAPI.hasAuthorization(this)) {
            onAuthorizationComplete();
        } else {
            startAuthentication();
        }
    }

    /**
     * To authorize the user.
     * Start user authentication and application authorization with Cloud API.
     */
    private void startAuthentication() {
        // Start the remote authentication
        cloudAPI.authorize(this);
    }

    /**
     * Called when the authorization is completed.
     */
    protected abstract void onAuthorizationComplete();
}
