/*
 * Copyright © 2015-2016, Verizon and/or its Licensors. All rights reserved.
 */

package com.thingspace.files.activity;

import android.graphics.Bitmap;
import android.graphics.drawable.BitmapDrawable;
import android.os.AsyncTask;
import android.os.Bundle;
import android.os.Environment;
import android.support.v7.app.AppCompatActivity;
import android.util.Log;
import android.view.Menu;
import android.view.MenuItem;
import android.view.View;
import android.widget.ImageView;
import android.widget.ProgressBar;
import android.widget.Toast;

import com.thingspace.cloud.sdk.CloudAPI;
import com.thingspace.files.R;
import com.thingspace.files.task.GetFileTask;
import com.thingspace.files.utils.KeplerUtil;

import java.io.File;
import java.io.FileOutputStream;

/**
 * Activity to display full screen photo and download file to the local storage.
 * This activity calls GetFileTask to view the full file by making cloud SDK API call.
 */
public class PhotoActivity extends AppCompatActivity {

    public static final String EXTRA_NAME = "extra_name";
    public static final String EXTRA_PARENT_PATH = "extra_parent_path";
    public static final String EXTRA_MIME_TYPE = "mime-type";
    public static final String EXTRA_CAPTURED_DATE = "capturedDate";
    public static final String EXTRA_WIDTH = "width";
    public static final String EXTRA_CREATED_DATE = "createdDate";
    public static final String EXTRA_HEIGHT = "height";
    public static final String EXTRA_SIZE = "size";

    private static CloudAPI cloudAPI;

    private ImageView fullPhoto;
    private ProgressBar progressBar;
    private String name;
    private String parentPath;
    private String mimeType;
    private String capturedDate;
    private String width;
    private String height;
    private Long size;

    private GetFileTask getFileTask;

    public static void setCloudAPI(CloudAPI aCloudAPI) {
        cloudAPI = aCloudAPI;
    }

    @Override
    protected void onCreate(Bundle savedInstanceState) {
        super.onCreate(savedInstanceState);
        setContentView(R.layout.activity_photo);
        fullPhoto = (ImageView) findViewById(R.id.imageFullPhoto);

        progressBar = (ProgressBar) findViewById(R.id.progressBarPhoto);

        mimeType = getIntent().getStringExtra(EXTRA_MIME_TYPE);
        capturedDate = getIntent().getStringExtra(EXTRA_CAPTURED_DATE);
        width = getIntent().getStringExtra(EXTRA_WIDTH);
        height = getIntent().getStringExtra(EXTRA_HEIGHT);
        size = getIntent().getLongExtra(EXTRA_SIZE, 0L);
        name = getIntent().getStringExtra(EXTRA_NAME);
        parentPath = getIntent().getStringExtra(EXTRA_PARENT_PATH);

        loadFullPhoto();
    }

    @Override
    public boolean onCreateOptionsMenu(Menu menu) {
        // Inflate the menu; this adds items to the action bar if it is present.
        getMenuInflater().inflate(R.menu.menu_photo, menu);
        return true;
    }

    @Override
    public boolean onOptionsItemSelected(MenuItem item) {

        switch (item.getItemId()) {
            case R.id.action_download:
                // Download the photo
                saveImageToSD();
                return true;
        }

        return super.onOptionsItemSelected(item);
    }

    private void loadFullPhoto() {
        if (!KeplerUtil.isNetworkAvailable(this)) {
            Toast.makeText(this, getString(R.string.error_unavailable), Toast.LENGTH_SHORT).show();
            finish();
            return;
        }

        progressBar.setVisibility(View.VISIBLE);
        if (getFileTask != null && !getFileTask.getStatus().equals(AsyncTask.Status.FINISHED)) {
            getFileTask.cancel(true);
        }
        /**
         * Get full file from the cloud by making cloud SDK API call.
         */
        getFileTask = new GetFileTask(parentPath, name, cloudAPI, fullPhoto, this, progressBar);
        getFileTask.execute();
    }

    /**
     * Retrieve the photo bytes from imageview bitmap and write it to the storage.
     */
    private void saveImageToSD() {
        File sdcard = Environment.getExternalStorageDirectory();

        File folder = new File(sdcard.getAbsoluteFile(), "VZDemoApp");//the dot makes this directory hidden to the user
        folder.mkdir();
        File file = new File(folder.getAbsoluteFile(), name);
        if (file.exists()) {
            Toast.makeText(this, getString(R.string.download_exist), Toast.LENGTH_SHORT).show();
            return;
        }

        try {
            FileOutputStream out = new FileOutputStream(file);
            ((BitmapDrawable) fullPhoto.getDrawable()).getBitmap().compress(Bitmap.CompressFormat.JPEG, 100, out);
            out.flush();
            out.close();

            Toast.makeText(this, getString(R.string.file_downloaded), Toast.LENGTH_SHORT).show();
        } catch (Exception e) {
            Log.e(getClass().getSimpleName(), "Exception downloading the photo: " + e);
        }
    }
}
