/*
 * Copyright © 2015-2016, Verizon and/or its Licensors. All rights reserved.
 */

package com.thingspace.files.task;

import android.content.Context;
import android.os.AsyncTask;
import android.util.Log;

import com.thingspace.cloud.sdk.exception.CloudAPIException;
import com.thingspace.cloud.sdk.list.item.File;
import com.thingspace.files.R;
import com.thingspace.files.listeners.DataFileOperationsResponseListener;

import java.lang.ref.WeakReference;

/**
 * Class to demonstrate API call to file operations on file using data type object.
 */
public class DataFileFOPSTask extends AsyncTask<String, Void, File> {

    private WeakReference<DataFileOperationsResponseListener> fileOperationsResponseListener;
    private String action, target;
    private Context context;
    private File file;

    /**
     * File operations using data type object
     *
     * @param context  Calling activity context
     * @param listener File operation response listener
     * @param file     File to be copied/moved/renamed
     * @param action   File operation
     * @param target   Target path for file.
     */
    public DataFileFOPSTask(Context context, DataFileOperationsResponseListener listener, File file, String action, String target) {
        this.context = context;
        fileOperationsResponseListener = new WeakReference<>(listener);
        this.file = file;
        this.action = action;
        this.target = target;
    }

    @Override
    protected File doInBackground(String... params) {
        try {
            if (action.equals(context.getString(R.string.action_copy))) {
                return file.copy(this.context, target, null, null, null);
            } else if (action.equals(context.getString(R.string.action_move))) {
                return file.move(this.context, target, null, null);
            } else if (action.equals(context.getString(R.string.action_rename))) {
                return file.rename(this.context, target, null, null);
            }

        } catch (CloudAPIException ex) {
            Log.e(getClass().getSimpleName(), "Exception retrieving resources: " + ex);
        }
        return null;
    }

    /**
     * @param response
     */
    @Override
    protected void onPostExecute(File response) {
        super.onPostExecute(response);

        if (action.equals(context.getString(R.string.action_copy))) {
            fileOperationsResponseListener.get().onDataCopyResponseReceived(response);
        } else if (action.equals(context.getString(R.string.action_move))) {
            fileOperationsResponseListener.get().onDataMoveResponseReceived(response);
        } else if (action.equals(context.getString(R.string.action_rename))) {
            fileOperationsResponseListener.get().onDataRenameResponseReceived(response);
        }
    }
}
