/*
 * Copyright © 2015-2016, Verizon and/or its Licensors. All rights reserved.
 */

package com.thingspace.files.task;

import android.content.Context;
import android.os.AsyncTask;
import android.util.Log;

import com.thingspace.cloud.sdk.CloudAPI;
import com.thingspace.cloud.sdk.exception.CloudAPIException;
import com.thingspace.files.listeners.FileOperationsResponseListener;
import com.thingspace.files.listeners.OnDeleteResponseListener;

import java.lang.ref.WeakReference;

/**
 * Class to demonstrate API call to Delete a file/folder in trash.
 */
public class DeleteTrashTask extends AsyncTask<String, Void, Boolean> {

    private static final String TAG = DeleteTrashTask.class.getName();
    private WeakReference<OnDeleteResponseListener> fileOperationsResponseListener;
    private CloudAPI cloudAPI;
    private Context context;

    /**
     * Empties the trash from cloud
     *
     * @param context  Calling activity context
     * @param listener {@link FileOperationsResponseListener} File operation response listener
     * @param cloudAPI {@link CloudAPI} object to access Cloud api
     */
    public DeleteTrashTask(Context context, OnDeleteResponseListener listener, CloudAPI cloudAPI) {
        this.context = context;
        fileOperationsResponseListener = new WeakReference<>(listener);
        this.cloudAPI = cloudAPI;
    }

    /**
     * @param params
     * @return
     */
    @Override
    protected Boolean doInBackground(String... params) {
        try {
            /**
             * Cloud SDK method call to empty the trash.
             */
            return cloudAPI.purgeTrash(this.context);
        } catch (CloudAPIException ex) {
            Log.e(getClass().getSimpleName(), "Exception retrieving resources: " + ex);
        }
        return false;
    }

    /**
     * @param response
     */
    @Override
    protected void onPostExecute(Boolean response) {
        super.onPostExecute(response);
        fileOperationsResponseListener.get().onDeleteResponseReceived(response);
    }
}