/*
 * Copyright © 2015-2016, Verizon and/or its Licensors. All rights reserved.
 */

package com.thingspace.files.task;

import android.app.Activity;
import android.os.AsyncTask;
import android.os.Environment;
import android.util.Log;
import android.widget.Toast;

import com.thingspace.cloud.sdk.CloudAPI;
import com.thingspace.cloud.sdk.exception.CloudAPIException;
import com.thingspace.files.R;
import com.thingspace.files.listeners.OnUploadDownloadResponseListener;

import java.io.File;
import java.lang.ref.WeakReference;

import javax.net.ssl.HttpsURLConnection;

/**
 * Class to demonstrate API call to download a file in device path.
 */
public class DownloadTask extends AsyncTask<String, Void, Boolean> {

    private WeakReference<Activity> activityWeakReference;
    private String parentPath, name;
    private CloudAPI cloudAPI;
    private int responseCode = -1;

    /**
     * Downloads a file from cloud to the device
     *
     * @param activity   Calling activity context
     * @param parentPath Files absolute path
     * @param name       File name to be downloaded from cloud
     * @param cloudAPI   {@link CloudAPI} object to access Cloud api
     */
    public DownloadTask(Activity activity, String parentPath, String name, CloudAPI cloudAPI) {
        activityWeakReference = new WeakReference<>(activity);
        this.parentPath = parentPath;
        this.name = name;
        this.cloudAPI = cloudAPI;
    }

    @Override
    protected Boolean doInBackground(String... params) {
        if (activityWeakReference.get() == null) {
            throw new IllegalArgumentException("activity reference null");
        }

        File sdcard = Environment.getExternalStorageDirectory();
        File folder = new File(sdcard.getAbsoluteFile(), "VZDemoApp");
        folder.mkdir();

        try {
            /**
             * Cloud SDK method call to download a file to the device
             */
            cloudAPI.downloadFile(activityWeakReference.get(), parentPath, name, folder.getAbsolutePath());
            return true;
        } catch (CloudAPIException ex) {
            Log.e(getClass().getSimpleName(), "Exception downloading file: " + ex);
            if (ex.getCode() == CloudAPIException.ErrorCode.USER_UNAUTHORIZED) {
                this.responseCode = HttpsURLConnection.HTTP_UNAUTHORIZED;
            } else if (ex.getCode() == CloudAPIException.ErrorCode.ERROR_LOST_CONNECTION) {
                this.responseCode = HttpsURLConnection.HTTP_UNAVAILABLE;
            }
        }
        return false;
    }

    @Override
    protected void onPostExecute(Boolean result) {
        super.onPostExecute(result);
        if (activityWeakReference.get() == null) {
            throw new IllegalArgumentException("activity reference null");
        }
        if (this.responseCode == HttpsURLConnection.HTTP_UNAUTHORIZED || this.responseCode == HttpsURLConnection.HTTP_UNAVAILABLE) {
            ((OnUploadDownloadResponseListener) activityWeakReference.get()).onUploadDownloadResponseReceived(false, this.responseCode);
            return;
        }
        Toast.makeText(activityWeakReference.get(), activityWeakReference.get().getString(result.booleanValue() ? R.string.file_downloaded : R.string.file_not_downloaded), Toast.LENGTH_SHORT).show();
    }
}
