/*
 * Copyright © 2015-2016, Verizon and/or its Licensors. All rights reserved.
 */

package com.thingspace.files.task;

import android.app.Activity;
import android.os.AsyncTask;

import com.thingspace.cloud.sdk.CloudAPI;
import com.thingspace.cloud.sdk.exception.CloudAPIException;
import com.thingspace.cloud.sdk.response.AccountInformation;
import com.thingspace.files.listeners.AccountInfoResponseListener;

import java.lang.ref.WeakReference;

import javax.net.ssl.HttpsURLConnection;

/**
 * Class to demonstrate API call to fetch account information of the user.
 */
public class GetAccountInfoTask extends AsyncTask<String, Void, AccountInformation> {

    private static final String TAG = GetAccountInfoTask.class.getName();
    private WeakReference<Activity> activityWeakReference;
    private CloudAPI cloudAPI;
    private int responseCode;
    private WeakReference<AccountInfoResponseListener> accountInfoResponseReference;

    /**
     * Fetches Account info of the user from the cloud
     * @param activity Calling activity context
     * @param cloudAPI {@link CloudAPI} object to access Cloud api
     * @param context  {@link AccountInfoResponseListener}Account info operation response listener
     */
    public GetAccountInfoTask(Activity activity, CloudAPI cloudAPI, AccountInfoResponseListener context) {
        accountInfoResponseReference = new WeakReference<AccountInfoResponseListener>(context);
        activityWeakReference = new WeakReference<>(activity);
        this.cloudAPI = cloudAPI;
    }

    /**
     * @param params
     * @return
     */
    @Override
    protected AccountInformation doInBackground(String... params) {

        if (activityWeakReference.get() == null) {
            throw new IllegalArgumentException("activity reference null");
        }
        try {
            /**
             * Cloud SDK method call to account info.
             */
            return cloudAPI.getAccountInformation(activityWeakReference.get());
        } catch (CloudAPIException cloudAPIException) {
            if (cloudAPIException.getCode() == CloudAPIException.ErrorCode.USER_UNAUTHORIZED) {
                this.responseCode = HttpsURLConnection.HTTP_UNAUTHORIZED;
            } else if (cloudAPIException.getCode() == CloudAPIException.ErrorCode.ERROR_LOST_CONNECTION) {
                this.responseCode = HttpsURLConnection.HTTP_UNAVAILABLE;
            }

        }
        return null;
    }


    /**
     * @param accountInformation
     */
    @Override
    protected void onPostExecute(AccountInformation accountInformation) {
        super.onPostExecute(accountInformation);


        if (activityWeakReference.get() == null) {
            throw new IllegalArgumentException("activity reference null");
        }

        accountInfoResponseReference.get().onAccountInfoResponseReceived(HttpsURLConnection.HTTP_OK, accountInformation);
    }
}
