/*
 * Copyright © 2015-2016, Verizon and/or its Licensors. All rights reserved.
 */

package com.thingspace.files.task;

import android.content.Context;
import android.os.AsyncTask;
import android.util.Log;

import com.thingspace.cloud.sdk.CloudAPI;
import com.thingspace.cloud.sdk.exception.CloudAPIException;
import com.thingspace.cloud.sdk.list.ItemList;
import com.thingspace.cloud.sdk.list.item.MetadataItem;
import com.thingspace.files.listeners.FileOperationsResponseListener;

import java.lang.ref.WeakReference;

import javax.net.ssl.HttpsURLConnection;

/**
 * Class to demonstrate API call to Rename a file/folder in target path.
 */
public class RenameFileFolderTask extends AsyncTask<String, Void, ItemList> {

    private WeakReference<FileOperationsResponseListener> fileOperationsResponseListener;
    private String src, target;
    private int responseCode;
    private Context context;
    private CloudAPI cloudAPI;

    /**
     * Renames File/Folder in cloud.
     *
     * @param context  Calling activity context
     * @param listener {@link FileOperationsResponseListener} File operation response listener
     * @param cloudAPI {@link CloudAPI} object to access Cloud api
     * @param src      Source path of the File/Folder in cloud
     * @param target   Target path of the File/Folder in cloud
     */
    public RenameFileFolderTask(Context context, FileOperationsResponseListener listener, CloudAPI cloudAPI, String src, String target) {
        this.context = context;
        fileOperationsResponseListener = new WeakReference<>(listener);
        this.cloudAPI = cloudAPI;
        this.src = src;
        this.target = target;
    }

    /**
     * @param params
     * @return
     */
    @Override
    protected ItemList doInBackground(String... params) {
        try {
            /**
             * Cloud SDK method call to rename a file/folder
             */
            return cloudAPI.rename(this.context, src, target, true, "copy");
        } catch (CloudAPIException ex) {
            Log.e(getClass().getSimpleName(), "Exception retrieving resources: " + ex);
            if (ex.getCode() == CloudAPIException.ErrorCode.USER_UNAUTHORIZED) {
                responseCode = HttpsURLConnection.HTTP_UNAUTHORIZED;
            } else if (ex.getCode() == CloudAPIException.ErrorCode.ERROR_HTTP_CODE) {
                return null;
            }
        }

        return null;
    }

    /**
     * @param response
     */
    @Override
    protected void onPostExecute(ItemList response) {
        super.onPostExecute(response);
        ItemList<MetadataItem> itemList = null;
        if (response != null) {
            responseCode = HttpsURLConnection.HTTP_OK;
            if (response instanceof ItemList) {
                itemList = (ItemList) response;
                for (int i = 0; i < itemList.getCount(); i++) {
                    MetadataItem metadataItem = itemList.getItem(i);
                    Log.d("------", metadataItem.getName());
                }
            }
        }
        fileOperationsResponseListener.get().onRenameResponseReceived(itemList, responseCode);
    }
}
