/*
 * Copyright © 2015-2016, Verizon and/or its Licensors. All rights reserved.
 */

package com.thingspace.files.task;

import android.content.Context;
import android.os.AsyncTask;
import android.util.Log;

import com.thingspace.cloud.sdk.CloudAPI;
import com.thingspace.cloud.sdk.exception.CloudAPIException;
import com.thingspace.files.listeners.OnDeleteResponseListener;

import java.lang.ref.WeakReference;
import java.util.ArrayList;

import javax.net.ssl.HttpsURLConnection;

/**
 * Class to demonstrate API call to Restore a file/folder from trash.
 */
public class RestoreTask extends AsyncTask<String, Void, Boolean> {

    private static final String TAG = RestoreTask.class.getName();
    private Context context;
    private WeakReference<OnDeleteResponseListener> fileOperationsResponseListener;
    private CloudAPI cloudAPI;
    private ArrayList<String> paths = new ArrayList<>();
    private int responseCode;

    /**
     * Restore File/Folder to source path in cloud from trash.
     *
     * @param context  Calling activity context
     * @param listener File operation response listener
     * @param cloudAPI {@link CloudAPI} object to access Cloud api
     * @param paths    List of file to be restored from trash
     */
    public RestoreTask(Context context, OnDeleteResponseListener listener, CloudAPI cloudAPI, ArrayList<String> paths) {
        this.context = context;
        fileOperationsResponseListener = new WeakReference<>(listener);
        this.cloudAPI = cloudAPI;
        this.paths = paths;
    }

    /**
     * @param params
     * @return
     */
    @Override
    protected Boolean doInBackground(String... params) {
        try {
            /**
             * Cloud SDK method call to Restore a file/folder from trash
             */
            return cloudAPI.restoreTrash(this.context, paths);
        } catch (CloudAPIException ex) {
            Log.e(getClass().getSimpleName(), "Exception restoring resources: " + ex);
            if (ex.getCode() == CloudAPIException.ErrorCode.USER_UNAUTHORIZED) {
                responseCode = HttpsURLConnection.HTTP_UNAUTHORIZED;
            } else if (ex.getCode() == CloudAPIException.ErrorCode.ERROR_FILE_ALREADY_EXIST) {
                responseCode = HttpsURLConnection.HTTP_OK;
            } else if (ex.getCode() == CloudAPIException.ErrorCode.ERROR_HTTP_CODE) {
                return false;
            }
        }

        return false;
    }

    /**
     * @param success
     */
    @Override
    protected void onPostExecute(Boolean success) {
        super.onPostExecute(success);
        fileOperationsResponseListener.get().onRestoreResponseReceived(success, responseCode);
    }
}